# ESSD_paper Zenodo code repository
## Code for management and processing of data for ESSD paper XYZ
### Authors: Samuel Weber, Jan Beutel, Matthias Meyer
### Copyright: ETH Zurich, 2019
### Version: 1.0, January 23,2019


## Subdirectories
* `gsn_data_management`
* `rtklib_processing`

## GSN DATA MANAGEMENT TOOLCHAIN
The Python3 GSN data management toolbox allows to:
* Query data from PermaSense GSN~server and save it locally as csv-files,
* Reload the locally stored csv-files,
* Filter according reference values if available,
* Clean data manually if needed,
* Generate 60-minute aggregates using in principle arithmetic mean (exceptions for weather data, see ESSD paper Weber et al., 2019),
* Export yearly csv-files for each position/location,
* Generate standard plots for all positions/locations as sanity check and
* Query images from PermaSense GSN~server and save it locally as jpg-files.

Note: Before you can use the function `get_GSNimg` in `manage_GSNdata.py`, you have to download NConvert and copy it in the directory `gsn_data_management`.

### NConvert
* NConvert is a powerful command line multi-platform batch image processor with more than 80 commands. Compatible with 500 image formats.
* NConvert is Multi-platform. It is available for Windows, Mac, Linux, FreeBSD, OS/2, DOS32 LE, MSDOS, ATARi,BeOS x86, QNX, Irix, Solaris, HP-UX, AIX, etc..
* Unrivaled Compatibility: NConvert is compatible with more than 500 formats (including Multipage and animated still formats APNG, TIFF, GIF, ICO, etc..) and Export to about 70 different file formats.
* **Download:** https://www.xnview.com/en/nconvert/


## RTKLIB PROCESSING TOOLCHAIN
===============================================================================
The open-source RTKLIB toolchain is a popular tool for processing GNSS data:

Tomoji, T.: RTKLIB: An Open Source Program Package for GNSSPositioning, http://www.rtklib.com, 2018.

It consists of a number of binary tools that can be used both in cmd-line mode and in combination with a GUI as well as the respective configuration files. In order to automate the processing of larger data sets we have developed a small toolchain that allows to prepare all data necessary and calculate double-differencing daily position solutions. In order to use this toolchain an operational installation of RTKLIB is required. For details on RTKLIB please refer to the respective tool documentation. The top-level shell script compute_solution.sh allows to specify a configuration parameter file, several options and the day for which processing is to be performed:

Usage: 
compute_solution.sh -p [parameter-file] [-d] [-b] [-r] [-c] [-f] [-u] YYYY MM DD

options:
  -d: IGS data download
  -b: no data download and no conversion for the basestation
  -r: no data download and no conversion for the roverstation
    -c: no conversion
    -f: use IGS final data product
    -u: upload to GSN database

The parameter file specified contains information on the baseline pair being processed, data products used and the exact locations of servers and directories to be used. The latter of which need to be adapted to suit your specific installation. The \verb+compute_solution.sh+ shell script calls further auxiliary programs written in python as well as tools from RTKLIB. The syntax is best explained using an example for computing positions MH42/HOGR and MH33 for the first day of the year 2017:

./compute_solution.sh -p parameter_file_HOGR_ZERM.txt -b -r -c -d -f 2017 01 01
./compute_solution.sh -p parameter_file_MH33.txt -b -f 2017 01 01

An example of how this toolchain can be used to compute daily positions for all Matterhorn GNSS positions for a given day is shown in the shell script gps_batch_compute.sh that can also be used to automate this process on a compute server.




