#!/bin/bash
#
# gps_batch_compute.sh job-script for running RTKLIB
#
# author: Jan Beutel
# (c) ETH Zurich, 2018
#
/bin/echo Starting on: `date`
/bin/echo Running on host: `hostname`
cd /usr/whymper/data-tik-02/permasense_vault/gps/rtklib_processing/bin
/bin/echo In directory: `pwd`
#/bin/echo Input: $1 $2    YEAR DoY
#

opt_final=false		  #bool indicating if the option -f is set
opt_upload=false		#bool indicating if the option -f is set
number_of_opts=0	  #count of chosen options
final_option=""

while getopts "fu" options; do
  case $options in
    f ) opt_final=true
    final_option="-f "
    #echo $final_option
    number_of_opts=$((number_of_opts+1))
    #echo $number_of_opts
  ;;
    u ) opt_upload=true
    upload_option="-u "
    number_of_opts=$((number_of_opts+1))
    #echo $number_of_opts
  ;;
	\?) echo "Invalid arguments. Usage: gps_batch_compute.sh -f -u YYYY DoY"
    	exit 1
  esac
done

#echo $number_of_opts
i=$((number_of_opts+1))
year=$(eval echo \${$i})
#echo $year
i=$((i+1))
DoYarg=$(eval echo \${$i})
#echo $DoYarg

if [ -z $DoYarg ]; then
    print "No Day of the year given."
    exit 1
else
  j=$DoYarg
  /bin/echo Computing position for year $year, single DoY $j
  year=$(date -d "$year-01-01 +$DoYarg days -1 day" "+%Y")
  month=$(date -d "$year-01-01 +$DoYarg days -1 day" "+%m")
  day=$(date -d "$year-01-01 +$DoYarg days -1 day" "+%d")
fi
# leap years 2012, 2016, 2020
if [ $j == "366" ]; then
  if [[ $1 =~ ^(2012|2016|2020)$ ]]; then
    echo "$1 is a leap year"
  else
    print "$1 is not a leap year"
    exit 1
  fi
fi

/bin/echo Computing position for: $year $month $day DoY $j
#			-d: igs data download
#			-b: no data download and no conversion for the basestation
#			-r: no data download and no conversion for the roverstation
#     -c: no conversion

# execute Matterhorn
# start 2011 02 02
./compute_solution.sh -p config/parameter_file_HOGR_ZERM.txt -b -r -c -d $final_option $upload_option $year $month $day

# # start 2014 08 14 or 16
./compute_solution.sh -p config/parameter_file_MH33.txt -b $final_option $upload_option $year $month $day
./compute_solution.sh -p config/parameter_file_MH34.txt -b $final_option $upload_option $year $month $day
# start 2015 06 02 or 3
./compute_solution.sh -p config/parameter_file_MH35.txt -b $final_option $upload_option $year $month $day
./compute_solution.sh -p config/parameter_file_MH40.txt -b $final_option $upload_option $year $month $day
./compute_solution.sh -p config/parameter_file_MH43.txt -b $final_option $upload_option $year $month $day

#
echo finished at: `date`
